@@ -22,7 +22,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 
 #include <string.h>
 #include <stdlib.h>
@@ -121,18 +121,16 @@ pango_win32_get_hfont (PangoFont *font)
  * pango_win32_get_context:
  *
  * Retrieves a #PangoContext appropriate for rendering with Windows fonts.
-  *
+ *
  * Return value: the new #PangoContext
+ *
+ * Deprecated: 1.22: Use pango_win32_font_map_for_display() followed by
+ * pango_font_map_create_context() instead.
  **/
 PangoContext *
 pango_win32_get_context (void)
 {
-  PangoContext *result;
-
-  result = pango_context_new ();
-  pango_context_set_font_map (result, pango_win32_font_map_for_display ());
-
-  return result;
+  return pango_font_map_create_context (pango_win32_font_map_for_display ());
 }
 
 G_DEFINE_TYPE (PangoWin32Font, _pango_win32_font, PANGO_TYPE_FONT)
@@ -586,7 +584,7 @@ pango_win32_font_get_metrics (PangoFont     *font,
 	      PangoLayout *layout;
 
 	      /*  Get the average width of the chars in "0123456789" */
-	      context = pango_win32_get_context ();
+	      context = pango_font_map_create_context (pango_win32_font_map_for_display ());
 	      pango_context_set_language (context, language);
 	      font_desc = pango_font_describe_with_absolute_size (font);
 	      pango_context_set_font_description (context, font_desc);
@@ -837,7 +835,9 @@ pango_win32_font_finalize (GObject *object)
 
   g_hash_table_destroy (win32font->glyph_info);
 
-  g_object_unref (win32font->fontmap);
+  g_assert (win32font->fontmap != NULL);
+  g_object_remove_weak_pointer (G_OBJECT (win32font->fontmap), (gpointer *) (gpointer) &win32font->fontmap);
+  win32font->fontmap = NULL;
 
   G_OBJECT_CLASS (_pango_win32_font_parent_class)->finalize (object);
 }
